==> elemental2-dom-1.1.0.jar: elemental2/dom/EventTarget.java <==
/*
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package elemental2.dom;

import jsinterop.annotations.JsFunction;
import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsType;
import jsinterop.base.Js;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public interface EventTarget {
  @JsFunction
  public interface AddEventListenerListenerFn {
    Object onInvoke(Event p0);
  }

  @JsType(isNative = true, name = "?", namespace = JsPackage.GLOBAL)
  public interface AddEventListenerOptionsUnionType {
    @JsOverlay
    static EventTarget.AddEventListenerOptionsUnionType of(Object o) {
      return Js.cast(o);
    }

    @JsOverlay
    default AddEventListenerOptions asAddEventListenerOptions() {
      return Js.cast(this);
    }

    @JsOverlay
    default boolean asBoolean() {
      return Js.asBoolean(this);
    }

    @JsOverlay
    default boolean isBoolean() {
      return (Object) this instanceof Boolean;
    }
  }

  @JsFunction
  public interface RemoveEventListenerListenerFn {
    Object onInvoke(Event p0);
  }

  @JsType(isNative = true, name = "?", namespace = JsPackage.GLOBAL)
  public interface RemoveEventListenerOptionsUnionType {
    @JsOverlay
    static EventTarget.RemoveEventListenerOptionsUnionType of(Object o) {
      return Js.cast(o);
    }

    @JsOverlay
    default boolean asBoolean() {
      return Js.asBoolean(this);
    }

    @JsOverlay
    default EventListenerOptions asEventListenerOptions() {
      return Js.cast(this);
    }

    @JsOverlay
    default boolean isBoolean() {
      return (Object) this instanceof Boolean;
    }
  }

  @JsOverlay
  default void addEventListener(
      String type, EventListener listener, AddEventListenerOptions options) {
    addEventListener(
        type, listener, Js.<EventTarget.AddEventListenerOptionsUnionType>uncheckedCast(options));
  }

  void addEventListener(
      String type, EventListener listener, EventTarget.AddEventListenerOptionsUnionType options);

  @JsOverlay
  default void addEventListener(String type, EventListener listener, boolean options) {
    addEventListener(
        type, listener, Js.<EventTarget.AddEventListenerOptionsUnionType>uncheckedCast(options));
  }

  void addEventListener(String type, EventListener listener);

  boolean dispatchEvent(Event evt);

  @JsOverlay
  default void removeEventListener(
      String type, EventListener listener, EventListenerOptions options) {
    removeEventListener(
        type, listener, Js.<EventTarget.RemoveEventListenerOptionsUnionType>uncheckedCast(options));
  }

  void removeEventListener(
      String type, EventListener listener, EventTarget.RemoveEventListenerOptionsUnionType options);

  @JsOverlay
  default void removeEventListener(String type, EventListener listener, boolean options) {
    removeEventListener(
        type, listener, Js.<EventTarget.RemoveEventListenerOptionsUnionType>uncheckedCast(options));
  }

  void removeEventListener(String type, EventListener listener);
}

==> elemental2-dom-1.3.2.jar: elemental2/dom/EventTarget.java <==
/*
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package elemental2.dom;

import jsinterop.annotations.JsFunction;
import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsType;
import jsinterop.base.Js;
import org.jspecify.annotations.Nullable;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public interface EventTarget {
  @JsFunction
  public interface AddEventListenerListenerFn {
    @Nullable Object onInvoke(Event p0);
  }

  @JsType(isNative = true, name = "?", namespace = JsPackage.GLOBAL)
  public interface AddEventListenerOptionsUnionType {
    @JsOverlay
    static EventTarget.AddEventListenerOptionsUnionType of(Object o) {
      return Js.cast(o);
    }

    @JsOverlay
    default AddEventListenerOptions asAddEventListenerOptions() {
      return Js.cast(this);
    }

    @JsOverlay
    default boolean asBoolean() {
      return Js.asBoolean(this);
    }

    @JsOverlay
    default boolean isBoolean() {
      return (Object) this instanceof Boolean;
    }
  }

  @JsFunction
  public interface RemoveEventListenerListenerFn {
    @Nullable Object onInvoke(Event p0);
  }

  @JsType(isNative = true, name = "?", namespace = JsPackage.GLOBAL)
  public interface RemoveEventListenerOptionsUnionType {
    @JsOverlay
    static EventTarget.RemoveEventListenerOptionsUnionType of(Object o) {
      return Js.cast(o);
    }

    @JsOverlay
    default boolean asBoolean() {
      return Js.asBoolean(this);
    }

    @JsOverlay
    default EventListenerOptions asEventListenerOptions() {
      return Js.cast(this);
    }

    @JsOverlay
    default boolean isBoolean() {
      return (Object) this instanceof Boolean;
    }
  }

  @JsOverlay
  default void addEventListener(
      String type, EventListener listener, AddEventListenerOptions options) {
    addEventListener(
        type, listener, Js.<EventTarget.AddEventListenerOptionsUnionType>uncheckedCast(options));
  }

  void addEventListener(
      String type, EventListener listener, EventTarget.AddEventListenerOptionsUnionType options);

  @JsOverlay
  default void addEventListener(String type, EventListener listener, boolean options) {
    addEventListener(
        type, listener, Js.<EventTarget.AddEventListenerOptionsUnionType>uncheckedCast(options));
  }

  void addEventListener(String type, EventListener listener);

  boolean dispatchEvent(Event evt);

  @JsOverlay
  default void removeEventListener(
      String type, EventListener listener, EventListenerOptions options) {
    removeEventListener(
        type, listener, Js.<EventTarget.RemoveEventListenerOptionsUnionType>uncheckedCast(options));
  }

  void removeEventListener(
      String type, EventListener listener, EventTarget.RemoveEventListenerOptionsUnionType options);

  @JsOverlay
  default void removeEventListener(String type, EventListener listener, boolean options) {
    removeEventListener(
        type, listener, Js.<EventTarget.RemoveEventListenerOptionsUnionType>uncheckedCast(options));
  }

  void removeEventListener(String type, EventListener listener);
}
